@@ -3,9 +3,10 @@ package Alien::FFI;
 use strict;
 use warnings;
 use 5.010;
+use Carp qw( croak );
 
 # ABSTRACT: Get libffi compiler and linker flags
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 
 sub new
@@ -33,6 +34,7 @@ sub cflags
   {
     $cflags = `$pkg_config --cflags libffi`;
     $cflags = '' unless $? == 0;
+    chomp $cflags;
   }
   
   $cflags;
@@ -46,11 +48,17 @@ sub libs
   {
     $libs = `$pkg_config --libs libffi`;
     $libs = '-lffi' unless $? == 0;
+    chomp $libs;
   }
   
   $libs;
 }
 
+sub dist_dir
+{
+  croak "Failed to find share dir for dist 'Alt-Alien-FFI-System'";
+}
+
 1;
 
 __END__
@@ -65,7 +73,7 @@ Alien::FFI - Get libffi compiler and linker flags
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
